@@ -3,7 +3,7 @@ package Wiki::Toolkit::Formatter::UseMod;
 use strict;
 
 use vars qw( $VERSION @_links_found );
-$VERSION = '0.24';
+$VERSION = '0.25';
 
 use URI::Escape;
 use Text::WikiFormat as => 'wikiformat';
@@ -51,6 +51,7 @@ A formatter backend for L<Wiki::Toolkit> that supports UseMod-style formatting.
                  edit_suffix         => '',
                  munge_urls          => 0,
                  external_link_class => 'external',
+                 escape_url_commas   => 1,
   );
 
 Parameters will default to the values shown above (apart from
@@ -71,6 +72,10 @@ Home node will have the URL C<wiki.pl?action=edit;id=Home>
 depend on how your wiki application processes its CGI parameters - you
 can't just put random stuff in there and hope it works!)
 
+By default, any commas in these URLs will be escaped to C<%2C>, in line
+with the default behaviour of L<URI::Escape>.  If you don't want this to
+happen, pass a false value to C<escape_url_commas>.
+
 =item B<Internal links - advanced options>
 
 If you wish to have greater control over the links, you may use the
@@ -224,6 +229,7 @@ sub _init {
                  munge_urls          => 0,
                  munge_node_name     => undef,
                  external_link_class => undef,
+                 escape_url_commas   => 1,
                );
 
     my %collated = (%defs, %args);
@@ -421,6 +427,10 @@ sub format_link {
     $link =~ s/ /_/g if $self->{_munge_urls};
     $link = uri_escape( $link );
 
+    unless ( $self->{_escape_url_commas} ) {
+        $link =~ s/%2C/,/gs;
+    }
+
     if ( $editlink_not_link ) {
         my $prefix = $self->{_edit_prefix};
         my $suffix = $self->{_edit_suffix};
